package org.fao.merge;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;

import javax.xml.transform.OutputKeys;
import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;

/**
 * Main class to merge XML documents. The default XSLT is xslt/merge.xsl
 * You can pass as command line argument the name of another xsl
 * @author celli
 *
 */
public class MergeXML {

	public static void main(String[] args){
		
		//select the xslt transformation
		String inputXSLT = SourceXMLCreator.xsltDir+"/merge.xsl";
		if(args.length == 1)
			inputXSLT = SourceXMLCreator.xsltDir+"/"+args[0];
		System.out.println("************* Applying transformation: "+inputXSLT+" *************");

		//delete if exists
		File deleteXMLfile = new File(SourceXMLCreator.outputDir+"/merged.xml");
		if(deleteXMLfile.exists())
			deleteXMLfile.delete();

		try{ 
			//build input XML
			(new SourceXMLCreator()).buildSourceXML();

			//streams
			Source xmlSource = new StreamSource(SourceXMLCreator.inputXML);
			Source xsltSource = new StreamSource(inputXSLT);
			Result result = new StreamResult(new FileOutputStream(SourceXMLCreator.outputDir+"/merged.xml"));


			//apply XSLT
			// create an instance of TransformerFactory
			TransformerFactory transFact = TransformerFactory.newInstance();
			Transformer trans = transFact.newTransformer(xsltSource);
			trans.setOutputProperty(OutputKeys.INDENT, "yes");
			trans.transform(xmlSource, result);

			System.out.println("************* The result is in "+SourceXMLCreator.outputDir+"/merged.xml *************");

			//delete input XML
			File deleteXMLinput = new File(SourceXMLCreator.inputXML);
			if(deleteXMLinput.exists())
				deleteXMLinput.delete();
		} catch(IOException e){
			e.printStackTrace();
		} catch (TransformerException e) {
			e.printStackTrace();
			e.getMessage();
		}
	}
}
