package org.fao.merge;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;

/**
 * This class is responsible for the creation of a source XML for the XSLT
 * that merges XMLs. This file goes into the XSLT directories and has the content:
 * <mergeDocs>
 * < doc path="file1.xml"/>
 * < doc path="file2.xml"/>
 *  ...
 *  </mergeDocs>
 *  
 * @author celli fabrizio
 *
 */
public class SourceXMLCreator {

	//static paths
	public static final String inputDir = "../X_SOURCE";
	public static final String outputDir = "../X_OUTPUT";
	public static final String xsltDir = "../xslt";
	public static final String inputXML = SourceXMLCreator.xsltDir+"/input.xml";

	public void buildSourceXML() throws IOException{	
		//create the input XML
		File inputXMLfile = new File(SourceXMLCreator.inputXML);
		System.out.println(inputXMLfile.getAbsolutePath());
		BufferedWriter out = new BufferedWriter(new FileWriter(inputXMLfile));
		out.write("<mergeDocs>");
		out.newLine();

		//apply to the directory
		File source = new File(SourceXMLCreator.inputDir);
		this.recursiveApplication(source, out);

		out.write("</mergeDocs>");
		out.flush();
		System.out.println("input XML created: "+inputXMLfile.getAbsolutePath());
	}	

	private void recursiveApplication(File source, BufferedWriter out) throws IOException{
		File[] listFiles = source.listFiles();
		for(File contentFile: listFiles){
			if(!contentFile.isDirectory()){
				String filename = contentFile.getName().toLowerCase();
				if(filename.contains(".xml")){
					out.write("<doc path=\""+contentFile.getAbsolutePath()+"\"/>");
					out.newLine();
				}
			}
			else {
				//recursive application
				this.recursiveApplication(contentFile, out);
			}
		}
	}

}
